#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-code-range-plugin-2.2.0.0-PDdnNQtgFBCdplfqQPdip
key:                  hls-code-range-plugin-2.2.0.0-PDdnNQtgFBCdplfqQPdip
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6777b9f69fc328176922f29fbf4f7b18
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-code-range-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.2.0.0-PDdnNQtgFBCdplfqQPdip
depends:
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE
    ghcide-2.2.0.0-3rbswqFiM3KCNOkb9FrghW
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    hls-plugin-api-2.2.0.0-BJo7BcpRHqCDcd0U20ikQY
    lens-5.3.3-Fsax7kDiNC56kOLwL7TDWM
    lsp-2.2.0.0-I9MBS7DrDvY58iJgT8duZO mtl-2.3.1
    semigroupoids-6.0.2-2YSDyrHLfWVJQ1SBKQg3K0 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

